{% extends "kegweb/drinkingsession_archive_base.html" %}
{% load tz %}
{% block title %}Sessions: {{year.year}} | {{ block.super }}{% endblock %}
{% block pagetitle %}Sessions: {{year.year}}{% endblock %}

{% block session-right %}
<ul>
  <li>
    <a href="{% url "kb-sessions" %}">All Sessions</a>
    <ul>
      <li>
        <b><a href="{% url "kb-sessions-year" year.year %}">{{year.year}}</a></b>
        <ul>
          {% for d in date_list %}
          <li>
            <a href="{% url "kb-sessions-month" d.year d.month %}">{{ d|utc|date:"F" }}</a>
          </li>
          {% endfor %}
        </ul>
      </li>
    </ul>
  </li>
</ul>
{% endblock %}
