{% extends "base.html" %}
{% load kegweblib %}
{% load bootstrap_pagination %}

{% block content %}
<div class="row">
<div class="span8">
{% for session in sessions %}
  {% include "kegweb/keg-session.html" %}
{% endfor %}
</div>

{% block session-right-hide %}
<div class="span4">
  <div class="well">
  <h4>All Sessions</h4>
  {% block session-right %}
  {% endblock %}
  </div>
</div>
{% endblock %}

</div>

<div class="row">
<div class="span8">
{% bootstrap_paginate page_obj range=10 %}
</div>
</div>

{% endblock %}
