{% extends "page-twocol.html" %}
{% load kegweblib %}

{% block title %}reset password{% endblock %}

{% block col-1 %}
<div class="kb-contentbox-head">
  password reset!
</div>
<div class="kb-contentbox">
  <p>
    you may now log in. bottoms up!
  </p>
</div>
{% endblock %}
