{% extends "page-twocol.html" %}
{% load kegweblib %}

{% block title %}System Stats | {{ block.super }}{% endblock %}
{% block pagetitle %}System Stats{% endblock %}

{% block col-1 %}
<h2>Summary</h2>

{% include "kegweb/basic-badges.html" %}
<table class="table table-condensed">
  <tbody>
    {% include "kegweb/basic-stats.html" %}
  </tbody>
</table>
{% endblock col-1 %}

{% block col-2 %}
  <h2>Top Drinkers</h2>
  {% chart users_by_volume stats 280 220 %}<br/>
  {% with top_drinkers as ranked_drinkers %}
    {% include "kegweb/drinker-rank.html" %}
  {% endwith %}
{% endblock col-2 %}
