{% extends "kegadmin/base.html" %}
{% load kegweblib %}

{% block title %}Kegbot Admin: Backup | {{ block.super }}{% endblock %}
{% block pagetitle %}Kegbot Admin: Backup{% endblock %}

{% block kegadmin-main %}
<div class="row">
  <div class="span11">
    <h2>Backup</h2>
    <div class="well">
      <p>
        <span class="label warning">Warning</span> This feature is currently
        <em>experimental</em>. For maximum safety, always perform a
        database-level backup, such as with <tt>mysqldump</tt>.
      </p>
      <h4>Select desired backup format.</h4>
      <p>
        <div class="row">
          <div class="span3">
            <a class="btn btn-success span2 pull-right "
                href="{% url "kegadmin-get-backup" %}?fmt=minjson">JSON (minimal)</a>
          </div>
          <div class="span7">
            <p>
              Minimized JSON text format.
            </p>
          </div>
        </div>
        <br/>

        <div class="row">
          <div class="span3">
            <a class="btn btn-success span2 pull-right "
                href="{% url "kegadmin-get-backup" %}?fmt=json">JSON (pretty)</a>
          </div>
          <div class="span7">
            <p>
              Pretty-printed JSON text format (largest file size).
            </p>
          </div>
        </div>
        <br/>

      </p>
    </div> <!-- /well -->
  </div> <!-- /span11 -->
</div>
{% endblock %}
